require 'spec_helper'

describe Puppet::Type.type(:ip_interface) do
  let(:required_params) do
    {
      :name   => '__name__',
      :ensure => 'present'
    }
  end
  let(:optional_params) do
    {
      # properties
      # parameters
        # :temporary => ,
    }
  end

  # Modify the params inline to tests when you modeling the
  # behavior of the generated resource
  let(:params) { required_params.merge(optional_params) }
  let(:resource) { described_class.new(params) }
  let(:provider) { Puppet::Provider.new(resource) }
  let(:catalog) { Puppet::Resource::Catalog.new }
  let(:error_pattern) { %r(failed on) }

  it "has :name as its keyattribute" do
    expect( described_class.key_attributes).to eq([:name])
  end

  describe "has property" do
    [
      # list properties
        :ensure,
    ].each { |prop|
      it prop do
        expect(described_class.attrtype(prop)).to eq(:property)
      end
    }
  end
  describe "has parameter" do
    [
        :name,
        :temporary,
    ].each { |param|
      it param do
        expect(described_class.attrtype(param)).to eq(:param)
      end
    }
  end

# Input Validation
describe "parameter" do
  [:name].each do |type|
    context "#{type}" do
      context "accepts" do
        %w(random_string).each do |thing|
          it thing.inspect do
            params[type] = thing
            expect { resource }.not_to raise_error
          end
        end
      end
      context "rejects" do
        %w().each do |thing|
          it thing.inspect do
            params[type] = thing
            expect { resource }.to raise_error(Puppet::Error, error_pattern)
          end
        end
      end
      it "fails/does not fail if unset" do
        params.delete(type)
        expect { resource }.to raise_error(Puppet::Error, %r(must be provided))
        expect { resource }.not_to raise_error
      end
      ## Test any munge behavior for parameter here
      #it "munges" do
      #  params[type] = %w(random_string)
      #  expect(resource[type]).to eq('other_string')
      #end
    end
  end
  [:temporary].each do |type|
    context "#{type}" do
      context "accepts" do
        %w(random_string).each do |thing|
          it thing.inspect do
            params[type] = thing
            expect { resource }.not_to raise_error
          end
        end
      end
      context "rejects" do
        %w().each do |thing|
          it thing.inspect do
            params[type] = thing
            expect { resource }.to raise_error(Puppet::Error, error_pattern)
          end
        end
      end
      it "fails/does not fail if unset" do
        params.delete(type)
        expect { resource }.to raise_error(Puppet::Error, %r(must be provided))
        expect { resource }.not_to raise_error
      end
      ## Test any munge behavior for parameter here
      #it "munges" do
      #  params[type] = %w(random_string)
      #  expect(resource[type]).to eq('other_string')
      #end
    end
  end
end # parameters

describe "property" do
    [:ensure].each do |type|
      context "#{type}" do
        context "accepts" do
          %w(random_string).each do |thing|
            it thing.inspect do
              params[type] = thing
              expect { resource }.not_to raise_error
            end
          end
        end
        context "rejects" do
          %w().each do |thing|
            it thing.inspect do
              params[type] = thing
              expect { resource }.to raise_error(Puppet::Error, error_pattern)
            end
          end
        end
        it "fails/does not fail if unset" do
          params.delete(type)
          expect { resource }.to raise_error(Puppet::Error, %r(must be provided))
          expect { resource }.not_to raise_error
        end
        ## Test any munge behavior for parameter here
        #it "munges" do
        #  params[type] = %w(random_string)
        #  expect(resource[type]).to eq('other_string')
        #end
      end
    end
end # properties


# describe "autorequire" do
#   # This assumes resource requires thing => two
#   it "does not require thing when no matching resource exists" do
#     thing = Puppet::Type.type(:thing).new(:name => "one")
#     catalog.add_resource thing
#     catalog.add_resource resource
#     expect(resource.autorequire.count).to eq 0
#   end
#   it "requires the matching thing resource" do
#     thing = Puppet::Type.type(:thing).new(:name => "two")
#     catalog.add_resource thing
#     catalog.add_resource resource
#     reqs = resource.autorequire
#     expect(reqs.count).to eq 1
#     expect(reqs[0].source).to eq thing
#     expect(reqs[0].target).to eq resource
#   end
# end
end
